agentle.agents.whatsapp.models.key
==================================

.. automodule:: agentle.agents.whatsapp.models.key

   
   .. rubric:: Functions

   .. autosummary::
   
      TypedDict
   
   .. rubric:: Classes

   .. autosummary::
   
      Key
   